library xwidgetbase;

import 'dart:async';
import 'dart:io';
import 'dart:typed_data';

import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:collection/collection.dart';
import 'package:provider/provider.dart';

import 'XStylesBase.dart';

part 'XWidgets/XCheckBoxWidget.dart';
part 'XWidgets/XContainerForImage.dart';
part 'XWidgets/XTreeNode.dart';
part 'XWidgets/XDrawer.dart';
part 'XWidgets/XAlertDIalog.dart';

part 'XWidgets/XBTN/XBtnBase.dart';
part 'XWidgets/XBTN/XBtnTakePhoto.dart';
part 'XWidgets/XBTN/XBtnReloader.dart';

part 'XWidgets/XItemsComplexWidgets/XItem.dart';
part 'XWidgets/XItemsComplexWidgets/XItemWidget.dart';
part 'XWidgets/XItemsComplexWidgets/Three_ConcatenatedXItem.dart';

part 'XWidgets/XTextFormField/XTextFormField.dart';
part 'XWidgets/XTextFormField/XTextFormFieldLogin.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithLabel.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithContainer.dart';

part 'XWidgets/XWidgetsForText/XCardForText.dart';
part 'XWidgets/XWidgetsForText/XContainerWithLabel.dart';
part 'XWidgets/XWidgetsForText/XTextWithLabel.dart';

part 'XfXWidgets/XfxElenco.dart';
part 'XfXWidgets/XfxItemForList.dart';
part 'XfXWidgets/XfxScheda.dart';
part 'XfXWidgets/XfxSchedaTapped.dart';

part 'XfXWidgets/XfxElencoWidgets/XColFilter.dart';
part 'XfXWidgets/XfxElencoWidgets/XHeaderWithSorting.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithDD.dart';

class XSearchBar extends StatelessWidget {
  final Function()? onPressed;
  final TextEditingController? controller;
  final String? labelText;
  final Color? iconColor;
  final Color? borderColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? labelStyle;
  final TextStyle? textStyle;
  final Widget? iconForSearch;
  final Widget? iconForClear;
  final InputBorder? enabledBorder;
  final InputBorder? disabledBorder;
  final InputBorder? border;
  final FocusNode? searchFocus;
  final bool autoFocus;
  final Function(String)? onTextChanged;
  final Function()? onPressedClear;
  final Function()? onPressedSearch;
  final Color? colorOfSearchBox;
  final Color? colorIconForClear;
  final Color? colorIconForSearch;
  final EdgeInsetsGeometry? marginOfSearchBox;
  final EdgeInsetsGeometry? paddingOfContent;
  late Timer timerSearch;

  final BoxDecoration? decorationOfContainerXSearch;

  XSearchBar({
    this.labelText,
    this.textStyle,
    this.controller,
    this.decorationOfContainerXSearch,
    this.colorIconForClear,
    this.colorIconForSearch,
    this.iconForClear,
    this.onPressedSearch,
    this.onPressed,
    this.iconColor,
    this.borderColor,
    this.hintText,
    this.hintStyle,
    this.labelStyle,
    this.iconForSearch,
    this.enabledBorder,
    this.disabledBorder,
    this.border,
    this.searchFocus,
    this.onTextChanged,
    this.onPressedClear,
    this.colorOfSearchBox,
    this.marginOfSearchBox,
    this.paddingOfContent,
    this.autoFocus = true,
  });
  // @override
  // onInit()
  // {
  //    timerSearch= Timer(Duration(milliseconds: 100), timerSearchHandlerList)
  // }
  // timerSearchHandlerList() {
  //   if (timerSearch != null) timerSearch!.cancel(); //fermo il mio chiamante
  //   if (searchFilter != "") {
  //     setState(() {
  //       filterCurrentForNave = searchFilter;
  //     });
  //   } else if (searchFilter == "") {
  //     setState(() {
  //       filterCurrentForNave = filterAllForNave;
  //     });
  //   }
  // }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Expanded(
          child: Container(
            margin: marginOfSearchBox ?? EdgeInsets.symmetric(vertical: 8),
            color: decorationOfContainerXSearch != null ? null : colorOfSearchBox ?? Colors.transparent,
            decoration: decorationOfContainerXSearch ?? null,
            child: Padding(
              padding: paddingOfContent ?? EdgeInsets.all(8.0),
              child: TextField(
                focusNode: searchFocus,
                autofocus: autoFocus,
                onChanged: onTextChanged,
                controller: controller,
                style: textStyle ?? XStyles.xStyTextForDescr(Colors.black),
                decoration: InputDecoration(
                    suffixIcon: Container(
                        width: 150,
                        child: Row(mainAxisAlignment: MainAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
                          IconButton(
                              onPressed: onPressedClear ??
                                  () {
                                    controller!.clear();
                                  },
                              icon: iconForClear ?? Icon(Icons.clear),
                              color: colorIconForClear ?? Colors.black),
                          IconButton(onPressed: onPressedSearch ?? () {}, icon: iconForSearch ?? Icon(Icons.search), color: colorIconForSearch ?? Colors.black),
                        ])),
                    labelText: labelText ?? null,
                    hintText: hintText ?? "Cerca",
                    hintStyle: hintStyle ?? XStyles.xStyTextForDescr(Colors.black),
                    labelStyle: labelStyle ?? XStyles.xStyTextForLabel(Colors.black),
                    enabledBorder: enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    disabledBorder: disabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    border: border ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0)))),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class XCircularProgressIndicator extends StatelessWidget {
  final String? label;
  final IconData? icon;
  XCircularProgressIndicator({
    this.label,
    this.icon,
  });

  @override
  Widget build(BuildContext context) {
    return Center(child: SizedBox(child: CircularProgressIndicator(strokeWidth: 8), height: 200.0, width: 200.0));
  }
}
